goverge
========
[![codecov.io](https://codecov.workiva.net/github/Workiva/goverge/coverage.svg?token=KOdniuD3F1&branch=master)](https://codecov.workiva.net/github/Workiva/goverge?branch=master)
goverge is a golang multi package coverage reporting tool.

Install
-------
    pip install goverge

Testing
-------
    pip install -r requirements_dev.txt
    nosetests

Contributing
-------
    Code: 
        Must be flake8 compliant -- pip install -r requirements_dev.txt to install flake8
        Must be unit tested
        Must have clear doc strings
    
